#!/usr/bin/sh
# 	Copyright (c) 2003-2008 The SCO Group, Inc. All Rights Reserved. 

#ident  "@(#)opensrc:src/curl/curl.sh /main/uw714mp/2"

#
# - dist/       curl/libcurl-7.15.1 distribution from
#               http://curl.haxx.se/download.html
# - curl.sh     Build script (this file).
# - curl.depend	Depend file
# - patches/*   Patches to be applied.
#

set -x
set -e


# Apply patches.

for patch in patches/7.15.1-uw.patch \
	patches/7.15.1-testcase.patch
do
       [ -f ${patch}.applied ] || {
               /usr/add-on/public/bin/patch -p0 -i ${patch}
               /bin/date > ${patch}.applied
       }
done



# Configure and build in a separate work directory.
mkdir -p work
cd work

../dist/configure --prefix=/usr \
	--with-ssl=/etc/ssl \
	--disable-ipv6 \
	--enable-ldap \
	--host=i386-unknown-sysv5UnixWare7.1.4 \
	--build=i386-unknown-sysv5UnixWare7.1.4 



# Prevent $MAKE from making Makefile, curl-config and libcurl.pc again.
/bin/ed Makefile <<-!
        /^all-am:/s/Makefile//
	/^all-am:/s/\$(SCRIPTS)//
	/^all-am:/s/\$(DATA)//
	w
	q
!
# Prevent $MAKE from making Makefile and config.h again.
/bin/ed lib/Makefile <<-!
        /^all-am:/s/Makefile//
	/^all-am:/s/config\.h//
	w
	q
!

/bin/ed src/Makefile <<-!
        /^all-am:/s/Makefile//
	/^all-am:/s/config\.h//
	w
	q
!

#
# Make libraries, and install header files and libraries in xenv.
#
$MAKE DESTDIR="$TOOLS" install-exec
rm ${TOOLS}/usr/lib/libcurl.la

# Now make everything and install in $ROOT/$MACH.
$MAKE DESTDIR="$ROOT/$MACH" install

#Install copyright files.
$INSTALL -d $ROOT/$MACH/usr/
$INSTALL -d $ROOT/$MACH/usr/share/
$INSTALL -d $ROOT/$MACH/usr/share/curl
$INSTALL -m 0444 ../dist/COPYING $ROOT/$MACH/usr/share/curl

# Install man pages in cat.1 and cat.3 directory.
MANDIR=$ROOT/$MACH/usr/man
$INSTALL -d $MANDIR/cat.1
# Install man pages in cat.1 directory.
/usr/ucb/nroff -man $MANDIR/man1/curl-config.1  > $MANDIR/cat.1/curl-config.1
/usr/ucb/nroff -man $MANDIR/man1/curl.1  > $MANDIR/cat.1/curl.1
$INSTALL -d $MANDIR/cat.3
# Install man pages in cat.3 directory.
/usr/ucb/nroff -man $MANDIR/man3/curl_easy_cleanup.3  > $MANDIR/cat.3/curl_easy_cleanup.3
/usr/ucb/nroff -man $MANDIR/man3/curl_easy_duphandle.3  > $MANDIR/cat.3/curl_easy_duphandle.3
/usr/ucb/nroff -man $MANDIR/man3/curl_easy_getinfo.3  > $MANDIR/cat.3/curl_easy_getinfo.3
/usr/ucb/nroff -man $MANDIR/man3/curl_easy_init.3  > $MANDIR/cat.3/curl_easy_init.3
/usr/ucb/nroff -man $MANDIR/man3/curl_easy_perform.3  > $MANDIR/cat.3/curl_easy_perform.3
/usr/ucb/nroff -man $MANDIR/man3/curl_easy_reset.3  > $MANDIR/cat.3/curl_easy_reset.3
/usr/ucb/nroff -man $MANDIR/man3/curl_easy_setopt.3  > $MANDIR/cat.3/curl_easy_setopt.3
/usr/ucb/nroff -man $MANDIR/man3/curl_easy_strerror.3  > $MANDIR/cat.3/curl_easy_strerror.3
/usr/ucb/nroff -man $MANDIR/man3/curl_escape.3  > $MANDIR/cat.3/curl_escape.3
/usr/ucb/nroff -man $MANDIR/man3/curl_formadd.3  > $MANDIR/cat.3/curl_formadd.3
/usr/ucb/nroff -man $MANDIR/man3/curl_formfree.3  > $MANDIR/cat.3/curl_formfree.3
/usr/ucb/nroff -man $MANDIR/man3/curl_free.3  > $MANDIR/cat.3/curl_free.3
/usr/ucb/nroff -man $MANDIR/man3/curl_getdate.3  > $MANDIR/cat.3/curl_getdate.3
/usr/ucb/nroff -man $MANDIR/man3/curl_getenv.3  > $MANDIR/cat.3/curl_getenv.3
/usr/ucb/nroff -man $MANDIR/man3/curl_global_cleanup.3  > $MANDIR/cat.3/curl_global_cleanup.3
/usr/ucb/nroff -man $MANDIR/man3/curl_global_init.3  > $MANDIR/cat.3/curl_global_init.3
/usr/ucb/nroff -man $MANDIR/man3/curl_global_init_mem.3  > $MANDIR/cat.3/curl_global_init_mem.3
/usr/ucb/nroff -man $MANDIR/man3/curl_mprintf.3  > $MANDIR/cat.3/curl_mprintf.3
/usr/ucb/nroff -man $MANDIR/man3/curl_multi_add_handle.3  > $MANDIR/cat.3/curl_multi_add_handle.3
/usr/ucb/nroff -man $MANDIR/man3/curl_multi_cleanup.3  > $MANDIR/cat.3/curl_multi_cleanup.3
/usr/ucb/nroff -man $MANDIR/man3/curl_multi_fdset.3  > $MANDIR/cat.3/curl_multi_fdset.3
/usr/ucb/nroff -man $MANDIR/man3/curl_multi_info_read.3  > $MANDIR/cat.3/curl_multi_info_read.3
/usr/ucb/nroff -man $MANDIR/man3/curl_multi_init.3  > $MANDIR/cat.3/curl_multi_init.3
/usr/ucb/nroff -man $MANDIR/man3/curl_multi_perform.3  > $MANDIR/cat.3/curl_multi_perform.3
/usr/ucb/nroff -man $MANDIR/man3/curl_multi_remove_handle.3  > $MANDIR/cat.3/curl_multi_remove_handle.3
/usr/ucb/nroff -man $MANDIR/man3/curl_multi_strerror.3  > $MANDIR/cat.3/curl_multi_strerror.3
/usr/ucb/nroff -man $MANDIR/man3/curl_share_cleanup.3  > $MANDIR/cat.3/curl_share_cleanup.3
/usr/ucb/nroff -man $MANDIR/man3/curl_share_init.3  > $MANDIR/cat.3/curl_share_init.3
/usr/ucb/nroff -man $MANDIR/man3/curl_share_setopt.3  > $MANDIR/cat.3/curl_share_setopt.3
/usr/ucb/nroff -man $MANDIR/man3/curl_share_strerror.3  > $MANDIR/cat.3/curl_share_strerror.3
/usr/ucb/nroff -man $MANDIR/man3/curl_slist_append.3  > $MANDIR/cat.3/curl_slist_append.3
/usr/ucb/nroff -man $MANDIR/man3/curl_slist_free_all.3  > $MANDIR/cat.3/curl_slist_free_all.3
/usr/ucb/nroff -man $MANDIR/man3/curl_strequal.3  > $MANDIR/cat.3/curl_strequal.3
/usr/ucb/nroff -man $MANDIR/man3/curl_unescape.3  > $MANDIR/cat.3/curl_unescape.3
/usr/ucb/nroff -man $MANDIR/man3/curl_version.3  > $MANDIR/cat.3/curl_version.3
/usr/ucb/nroff -man $MANDIR/man3/curl_version_info.3  > $MANDIR/cat.3/curl_version_info.3
/usr/ucb/nroff -man $MANDIR/man3/libcurl-easy.3  > $MANDIR/cat.3/libcurl-easy.3
/usr/ucb/nroff -man $MANDIR/man3/libcurl-errors.3  > $MANDIR/cat.3/libcurl-errors.3
/usr/ucb/nroff -man $MANDIR/man3/libcurl-multi.3  > $MANDIR/cat.3/libcurl-multi.3
/usr/ucb/nroff -man $MANDIR/man3/libcurl-share.3  > $MANDIR/cat.3/libcurl-share.3
/usr/ucb/nroff -man $MANDIR/man3/libcurl-tutorial.3  > $MANDIR/cat.3/libcurl-tutorial.3
/usr/ucb/nroff -man $MANDIR/man3/libcurl.3  > $MANDIR/cat.3/libcurl.3

#$MAKE test

exit 0
